==> fms-0.0.3.tgz: package/src/init.js <==
var colors = require('colors')
var fs = require('fs')
var fse = require('fs-extra')
var _ = require('underscore')
var hljs = require('highlight.js')
var marked = require('marked')
var Handlebars = require('handlebars')

var _util = require('./util')
var doc = require('./doc')
var path = require('path')

var init = function (settings) {
    var $ = require('../index')
    var server = require('./server')

    // 支持 $.run(18080) 语法
    if (typeof settings !== 'object') {
        settings = {
            port: settings
        }
    }

    var defaultConfig = require('./config')
    $.extend(true, defaultConfig, settings)
    $.config = defaultConfig

    $.config.port = process.env.PORT || $.config.port

    // 始终读取项目根目录 HTML 文件
    $.config.html.push('/')
    $.config.html = _.uniq($.config.html)

    // Ref: https://github.com/nimojs/fms/issues/9
    // urlRewrite String 前缀自动修复
    $.config.urlRewrite.forEach(function (value, index, arr) {
        // 偶数跳过
        if (index%2) {
            return
        }
        var searchValue = value
        if (typeof searchValue === 'string') {
            if (searchValue.charAt(0) !== '/' && searchValue.length !== 0) {
                var newValue = '/' + searchValue
                arr[index] = newValue
                console.log(('"' + searchValue + '" changed to "' + newValue + '"').yellow)
                // "s/" changed to "/s/"
            }
        }
        
    })
    
    _.each($.config.smarty.plugin, function (plugin, type) {
        _.each(plugin, function (fn, name) {
            $.smarty.prototype.registerPlugin(
                type,
                name,
                fn
            )
        })
    })

    // {include file="..."}
    jSmart.prototype.getTemplate = function(path) {
        var includeTpl = fs.readFileSync($._cwd + '/' + $.config.smarty.includePath + path, 'utf-8')
        return includeTpl
    }

    // 生成文档 markdown 和 html 文档
    // 需要延迟执行，因为文档内容是由 $.ajax $.page $.doc 生成的，而这些函数是比 $.run 后执行的
    setTimeout(function(){// setTimeout Start
    var aMarkdownDoc = []

    doc._data.forEach(function (value) {
        /*
            oRenderData: 是 $.ajax $.page 中 settings 的扩展
            它完全复制了 settings 并且为了成为文档渲染的渲染数据源做了一些优化
            例如: oRenderData.title = oRenderData.title || oRenderData.url;
         */
        var settings = value.settings
        var oRenderData = $.extend(true, {}, settings)

        var request = oRenderData.request || false
        if (typeof request === 'object') {
            request = '\r\n```js\r\n' + _util.formatJson(JSON.stringify(request)) + '\r\n```\r\n'
        }
        oRenderData.request = request
        oRenderData.title = oRenderData.title || oRenderData.url
        if (value.type === 'ajax' || value.type === 'page')
        if (typeof settings.doc === 'function') {
            settings.doc = $.heredoc(settings.doc)
            // {{success}} to {{&success}}
            settings.doc = settings.doc.replace(/{{(success|error|url|title|data)}}/g,'{{&$1}}');
        }

        switch (value.type) {
            case 'ajax':
                var fTransitionResult = function (target) {
                    switch (typeof(target)) {
                        case 'object':
                            if (settings.mock) {
                                target = Mock.mock(target);
                            }
                            target = _util.formatJson(JSON.stringify(target))
                        break;

                        case 'number':
                            target = String(target);
                        break;

                        case 'function':
                        target = null;
                        break;

                        default:
                    }
                    return target;
                };

                oRenderData.success = fTransitionResult(settings.success)
                oRenderData.error = fTransitionResult(settings.error)

                

                aMarkdownDoc.push('<a href="#' + oRenderData.url + '" class="markdown-anchor" data-url="' + oRenderData.url + '" data-type="ajax" name="' + oRenderData.url + '">#</a>\r\n');

                aMarkdownDoc.push(Handlebars.compile(settings.doc)(oRenderData))
            break
            case 'page':

                _.each($.config.smarty.docDataFilter, function (name) {
                    delete oRenderData.data[name]
                })
                oRenderData.data = _util.formatJson(JSON.stringify(oRenderData.data))

                
                // 注意：这里多了一个 !page 作为 ajax 和 page 的区分
                aMarkdownDoc.push('<a href="#' + oRenderData.url + '!page" class="markdown-anchor" data-url="' + oRenderData.url + '" data-type="page" name="' + oRenderData.url + '!page">#</a>\r\n');

                aMarkdownDoc.push(Handlebars.compile(settings.doc)(oRenderData))
            break
            case 'template':
                aMarkdownDoc.push('\n \n' + Handlebars.compile(value.template)(value.renderData))
            break
            default:
        }
    })
    aMarkdownDoc.push('<!-- Created by fms.nimojs.com  -->')
    
    marked.setOptions({
        highlight: function (code, lang, callback) {
            if (lang) {
                return hljs.highlight(lang, code).value
            }
            else {
                return hljs.highlightAuto(code).value
            }
        }
    })
    
    $._data.doc_html = marked(aMarkdownDoc.join('\r\n \r\n'))

    var docHtmlTemplate = fs.readFileSync(__dirname + '/handlebars/doc-html.hbs', 'utf-8')
    var html = Handlebars.compile(docHtmlTemplate)({
        content: $._data.doc_html
    })
    console.log($._data.ajaxs)
    console.log($._data.pages)
    if ($.config.docPath) {
        fse.outputFileSync(path.join($._cwd + '/' + $.config.docPath), html)
    }
    }, 10)// setTimeout End
    server()
}

module.exports = init

==> fms-0.0.5.tgz: package/src/init.js <==
var colors = require('colors')
var fs = require('fs')
var fse = require('fs-extra')
var _ = require('underscore')
var hljs = require('highlight.js')
var marked = require('marked')
var Handlebars = require('handlebars')

var _util = require('./util')
var doc = require('./doc')
var path = require('path')

var init = function (settings) {
    var $ = require('../index')
    var server = require('./server')

    // 支持 $.run(18080) 语法
    if (typeof settings !== 'object') {
        settings = {
            port: settings
        }
    }

    var defaultConfig = require('./config')
    $.extend(true, defaultConfig, settings)
    $.config = defaultConfig

    $.config.port = process.env.PORT || $.config.port

    // 始终读取项目根目录 HTML 文件
    $.config.html.push('/')
    $.config.html = _.uniq($.config.html)

    // Ref: https://github.com/nimojs/fms/issues/9
    // urlRewrite String 前缀自动修复
    // 因为与 combo 不好共存暂时先注释
    // $.config.urlRewrite.forEach(function (value, index, arr) {
    //     // 偶数跳过
    //     if (index%2) {
    //         return
    //     }
    //     var searchValue = value
    //     if (typeof searchValue === 'string') {
    //         if (searchValue.charAt(0) !== '/' && searchValue.length !== 0) {
    //             var newValue = '/' + searchValue
    //             arr[index] = newValue
    //             console.log(('"' + searchValue + '" changed to "' + newValue + '"').yellow)
    //             // "s/" changed to "/s/"
    //         }
    //     }
    // })
    
    _.each($.config.smarty.plugin, function (plugin, type) {
        _.each(plugin, function (fn, name) {
            $.smarty.prototype.registerPlugin(
                type,
                name,
                fn
            )
        })
    })

    // {include file="..."}
    jSmart.prototype.getTemplate = function(path) {
        var includeTpl = fs.readFileSync($._cwd + '/' + $.config.smarty.includePath + path, 'utf-8')
        return includeTpl
    }

    // 生成文档 markdown 和 html 文档
    // 需要延迟执行，因为文档内容是由 $.ajax $.page $.doc 生成的，而这些函数是比 $.run 后执行的
    setTimeout(function(){// setTimeout Start
    var aMarkdownDoc = []

    doc._data.forEach(function (value) {
        /*
            oRenderData: 是 $.ajax $.page 中 settings 的扩展
            它完全复制了 settings 并且为了成为文档渲染的渲染数据源做了一些优化
            例如: oRenderData.title = oRenderData.title || oRenderData.url;
         */
        var settings = value.settings
        var oRenderData = $.extend(true, {}, settings)

        var request = oRenderData.request || false
        if (typeof request === 'object') {
            request = '\r\n```js\r\n' + _util.formatJson(JSON.stringify(request)) + '\r\n```\r\n'
        }
        oRenderData.request = request
        oRenderData.title = oRenderData.title || oRenderData.url
        if (value.type === 'ajax' || value.type === 'page')
        if (typeof settings.doc === 'function') {
            settings.doc = $.heredoc(settings.doc)
            // {{success}} to {{&success}}
            settings.doc = settings.doc.replace(/{{(success|error|url|title|data)}}/g,'{{&$1}}');
        }

        switch (value.type) {
            case 'ajax':
                var fTransitionResult = function (target) {
                    switch (typeof(target)) {
                        case 'object':
                            if (settings.mock) {
                                target = Mock.mock(target);
                            }
                            target = _util.formatJson(JSON.stringify(target))
                        break;

                        case 'number':
                            target = String(target);
                        break;

                        case 'function':
                        target = null;
                        break;

                        default:
                    }
                    return target;
                };

                oRenderData.success = fTransitionResult(settings.success)
                oRenderData.error = fTransitionResult(settings.error)

                

                aMarkdownDoc.push('<a href="#' + oRenderData.url + '" class="markdown-anchor" data-url="' + oRenderData.url + '" data-type="ajax" name="' + oRenderData.url + '">#</a>\r\n');

                aMarkdownDoc.push(Handlebars.compile(settings.doc)(oRenderData))
            break
            case 'page':

                _.each($.config.smarty.docDataFilter, function (name) {
                    delete oRenderData.data[name]
                })
                oRenderData.data = _util.formatJson(JSON.stringify(oRenderData.data))

                
                // 注意：这里多了一个 !page 作为 ajax 和 page 的区分
                aMarkdownDoc.push('<a href="#' + oRenderData.url + '!page" class="markdown-anchor" data-url="' + oRenderData.url + '" data-type="page" name="' + oRenderData.url + '!page">#</a>\r\n');

                aMarkdownDoc.push(Handlebars.compile(settings.doc)(oRenderData))
            break
            case 'template':
                aMarkdownDoc.push('\n \n' + Handlebars.compile(value.template)(value.renderData))
            break
            default:
        }
    })
    aMarkdownDoc.push('<!-- Created by fms.nimojs.com  -->')
    
    marked.setOptions({
        highlight: function (code, lang, callback) {
            if (lang) {
                return hljs.highlight(lang, code).value
            }
            else {
                return hljs.highlightAuto(code).value
            }
        }
    })
    
    $._data.doc_html = marked(aMarkdownDoc.join('\r\n \r\n'))

    var docHtmlTemplate = fs.readFileSync(__dirname + '/handlebars/doc-html.hbs', 'utf-8')
    var html = Handlebars.compile(docHtmlTemplate)({
        content: $._data.doc_html
    })
    if ($.config.docPath) {
        fse.outputFileSync(path.join($._cwd + '/' + $.config.docPath), html)
    }
    }, 10)// setTimeout End
    server()
}

module.exports = init
